\name{conditional.rareMETALS.single.basic}
\alias{conditional.rareMETALS.single.basic}
\title{
This function performs conditional meta-analysis for single variant association test
using shared single variant score statistics and covariance matrix
}
\description{
  The function implements the method of RARE-METALS for performing
  single variant association test. By sharing information on single variant
  score statistics, and their variance-covariance matrix within a
  sliding window, conditional association analysis can be performed,
  which can be critical for dissecting indepdent association signals.
}
\usage{
conditional.rareMETALS.single.basic(candidate.variant,score.stat.file,cov.file,known.variant.vec,maf.cutoff,no.boot=0,alternative=c('two.sided','greater','less'),alpha=0.05,ix.gold=1,out.digits=4,callrate.cutoff=0,hwe.cutoff=0,gene.file="refFlat_hg19.txt.gz",p.value.known.variant.vec="N/A",anno.known.variant.vec="N/A",anno.candidate.variant="N/A")
}
\arguments{
  \item{candidate.variant}{The candidate variant to be tested. The
    variable is a string, which must have the form of "1:12345" etc. }
  \item{score.stat.file}{
    Vector of file names of score statistic file. The file needs to be
    bgzip compressed and tabix indexed. 
  }
  \item{cov.file}{Vector of file names of covariance matrix file. The file needs to be
    bgzip compressed and tabix indexed. 
  }
  \item{maf.cutoff}{Minor allele frequency cutoff to be used to select variants for
    gene-level test. }
  \item{no.boot}{Number of bootstraps to be performed. }
  \item{alternative}{Alternative hypothesis to be tested. For GRANVIL test, options
    include two.sided, greater and less. For SKAT and VT test, only
    two.sided option is supported.}
  \item{alpha}{Significance threshold. This option is used with no.boot
    parameter. It will determine the number of bootstraps to be performed}
  \item{callrate.cutoff}{The default value is set for callrate is
    0.9. Variant sites with call rate below 0.9 is automatically labeled
    as NA.}
  \item{hwe.cutoff}{The default value for Hardy Weinberg p-value cutoff is 1e-7. Sites
    with extreme HWE p-values are labeled as NA.}
  \item{ix.gold}{Gold standard population. Since there may be
    incompatible allele labels between different studies, it may be
    helpful to specify a gold standard population, with which allele
    labels can be compared and corrected correspondingly.  } 
  \item{out.digits}{Specify output digits for numerical values, such as
    p.values etc.  }
  \item{gene.file}{File name for refFlat table resource file.  }
  \item{p.value.known.variant.vec}{P values of known variants. The
    variable is optional, and may be set as "NA" if ignored. }
  \item{anno.known.variant.vec}{Annotation information for known
    variant. It is optional and can be ignored.}
  \item{anno.candidate.variant}{Annotation information for candidate
    variant. It is optional and can be ignored.}
}
\details{
  
}
\value{
  
}
\references{
  Liu DJ et al Meta-analysis of Gene-level Associations, submitted, 2013
}
\author{
  Dajiang J. Liu
}
\note{
  
}
\seealso{
  
}
\examples{

}
